Class Window API exported by pygame.window — pygame-ce v2.3.2 documentation

##### pygame-ce documentation

Pygame-ce Home || Help Contents || Reference Index

Most useful stuff: Color | display | draw | event | font | image | key | locals | mixer | mouse | Rect | Surface | time | music | pygame

Advanced stuff: cursors | joystick | mask | sprite | transform | BufferProxy | freetype | gfxdraw | midi | PixelArray | pixelcopy | sndarray | surfarray | math

Other: camera | controller | examples | scrap | system | tests | touch | version

## src_c/window.c

This extension module defines Python type `pygame.Window`.

Header file: src_c/include/pygame.h

type pgWindowObject

  A `pygame.window.Window` instance.

PyTypeObject *pgWindow_Type

  The `pygame.window.Window` Python type.

int pgWindow_Check(PyObject *x)

  Return true if x is a `pygame.window.Window` instance

  Will return false if x is not a subclass of Window. This is a macro. No check is made that x is not NULL.

Edit on GitHub